//---------------------------------------------------------------------------
// Copyright (C) 2003 Dallas Semiconductor Corporation, All Rights Reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// Except as contained in this notice, the name of Dallas Semiconductor
// shall not be used except as stated in the Dallas Semiconductor
// Branding Policy.
//---------------------------------------------------------------------------
//
//  TMLine.C - This utility calls the TMLine function to alter the 1-Wire
//             communication attributes.
//
//  Compiler:  Microsoft Visual C 
//  Version:   0.00
//
//

#define TMEXUTIL

#include "uline.h"   

// Local Function Prototypes 
void Exit_Prog(char *, short);

// Global Variables to hold list information 
short PortType, PortNum;
uchar state_buffer[5120];
ushort CRC16;
short ROM[9];

char pdsr[][20] = { "15 V/us", "2.20 V/us", "1.65 V/us", "1.37 V/us",
                    "1.10 V/us", "0.83 V/us", "0.70 V/us", "0.55 V/us" };

char w1lt[][20] = { "8 us", "9 us", "10 us", "11 us",
                    "12 us", "13 us", "14 us", "15 us" };

char ds0[][20]  = { "3 us", "4 us", "5 us", "6 us",
                     "7 us", "8 us", "9 us", "10 us" };

//----------------------------------------------------------------------
//  This is the Main routine 
//
void main(short argc, char **argv)
{
   short writelen=0,i,loop=0,printmsg;
   char tstr[200],ch;       
   long session_handle;
   LineType Line;

   // check arguments to see if request instruction with '?' or too many 
   if (argc != 1)
   {
       printf("\nusage: TMLine\n"
              "  - version 0.00\n");
       Exit_Prog("",BAD_ARGUMENT);
   }

   // read the default PortNum and PortType 
   if (!TMReadDefaultPort(&PortNum,&PortType))
       Exit_Prog("ERROR, Could not read the default PortNum and PortType from registry!\n",
               NO_DRIVERS);

   // print a header  
   printf("\nTMLine 1-Wire line attribute utility, Version 0.00\n"
         "Dallas Semiconductor Corporation / Maxim\n"); 
   printf("Default port number: %d    port type: %d\n\n",PortNum,PortType);
   Get_Version(tstr);
   printf("TMEX main driver:\n %s\n",tstr);
   printf("TMEX adapter driver, Type%d:\n",PortType);
   if (TMGetTypeVersion(PortType,tstr) < 0)
      Exit_Prog("No Hardware Driver for this type found!",NO_DRIVERS);
   printf(" %s\n\n",tstr);

   // check type
   if (strstr(tstr,"9097U") != NULL)
      sprintf(Line.ID,"DS2480");
   else if (strstr(tstr,"9490") != NULL)
      sprintf(Line.ID,"DS2490");
   else
      Exit_Prog("Default adapter type does not use DS2480B or DS2490!\n",NO_DRIVERS);

   // loop to select values and set them
   for (;;)
   {
      // attempt to get a session
      printmsg = TRUE;
      do
      {
         session_handle = TMExtendedStartSession(PortNum,PortType,NULL);
         if (session_handle > 0)  
         {
            if (TMSetup(session_handle) == 1)
            {
               // read line settings
               Line.Operation = READ_FUNCTION;
               if (TMLine(session_handle,&Line) != 1)
               {
                  TMEndSession(session_handle);
                  Exit_Prog("Failed to read 1-Wire line settings!\n",-1);
               }
               break;
            }
            else
            {
               TMEndSession(session_handle);
               Exit_Prog("Failed setup!\n",NO_DRIVERS);
            }
         }
         else if (session_handle == 0)
         {                            
            if (printmsg)
            {
               printf("\nWaiting to get access to the 1-Wire port\n\n");
               printmsg = FALSE;
            }
         }
         else if (session_handle < 0)   
         {
            TMEndSession(session_handle);
            Exit_Prog("No Hardware Driver for this type found!\n",NO_DRIVERS);
         }
      }
      while (!kbhit());

      // end the session 
      TMEndSession(session_handle);

      // print the current line state
      printf("\nCurrent (STANDARD) 1-Wire line settings:\n");
      printf(" PDSR  = %s\n",&pdsr[(Line.NormalDefault.PDSRC >> 1)][0]);
      printf(" W1LT  = %s\n",&w1lt[(Line.NormalDefault.W1LT >> 1)][0]);
      printf(" DSOW0 = %s\n",&ds0[(Line.NormalDefault.DSOWORT >> 1)][0]);

      // select the new values
      do
      {
         printf("\nSelect the PDSR (pulldown slew rate):\n");
         for (i = 0; i < 8; i++)
            printf(" %d) %s\n",i,&pdsr[i][0]);
         printf(" 8) EXIT\n");

         printf("\nEnter number: ");
         ch = getche();
         if (ch == '8')
            Exit_Prog("\nEnd.",0);
         Line.NormalDefault.PDSRC = (ch - '0') << 1;
         printf("\n");
      }
      while ((Line.NormalDefault.PDSRC < 0) || (Line.NormalDefault.PDSRC > 14)); 

      do
      {
         printf("\nSelect the W1LT (write-1 low time):\n");
         for (i = 0; i < 8; i++)
            printf(" %d) %s\n",i,&w1lt[i][0]);
         printf(" 8) EXIT\n");

         printf("\nEnter number: ");
         ch = getche();
         if (ch == '8')
            Exit_Prog("\nEnd.",0);
         Line.NormalDefault.W1LT = (ch - '0') << 1;
         printf("\n");
      }
      while ((Line.NormalDefault.W1LT < 0) || (Line.NormalDefault.W1LT > 14)); 

      do
      {
         printf("\nSelect the DSO/WOR (data sample offset / write-0 recovery):\n");
         for (i = 0; i < 8; i++)
            printf(" %d) %s\n",i,&ds0[i][0]);
         printf(" 8) EXIT\n");

         printf("\nEnter number: ");
         ch = getche();
         if (ch == '8')
            Exit_Prog("\nEnd.",0);
         Line.NormalDefault.DSOWORT = (ch - '0') << 1;
         printf("\n");
      }
      while ((Line.NormalDefault.DSOWORT < 0) || (Line.NormalDefault.DSOWORT > 14)); 

      // set the values
      printf("\n------ Writing 1-Wire line settings ------\n");
      printmsg = TRUE;
      do
      {
         session_handle = TMExtendedStartSession(PortNum,PortType,NULL);
         if (session_handle > 0)  
         {
            // read line settings
            Line.Operation = WRITE_FUNCTION;
            if (TMLine(session_handle,&Line) != 1)
            {
               TMEndSession(session_handle);
               Exit_Prog("Failed to write 1-Wire line settings!\n",-1);
            }
            break;
         }
         else if (session_handle == 0)
         {                            
            if (printmsg)
            {
               printf("\nWaiting to get access to the 1-Wire port\n\n");
               printmsg = FALSE;
            }
         }
         else if (session_handle < 0)   
         {
            TMEndSession(session_handle);
            Exit_Prog("No Hardware Driver for this type found!\n",NO_DRIVERS);
         }
      }
      while (!kbhit());

      // end the session 
      TMEndSession(session_handle);
   }
}


/*--------------------------------------------------------------------------
 *  Prints a message, beeps and exits the program.
 */
void Exit_Prog(char *msg, short errcd)
{
   /* print the message left justified */
   printf("\r%s",msg);
   
   /*  error beep if return code is not 0 */
   if (errcd != NORMAL_EXIT)
     MessageBeep(MB_ICONEXCLAMATION);
   
   /*  return error code passed */
   exit(errcd);
}

         
        /* 
         
         for (loop = 0; loop < 2; loop++)
         {
            // READ ROM
            if (TMTouchReset(session_handle) != 1)
              Exit_Prog("No presence\n",NO_DEVICE);

            buf[0] = 0x33;
            for (i = 1; i <= 8; i++)
               buf[i] = 0xFF;

            TMBlockStream(session_handle, buf, 9);

            printf("READ ROM:   ");
            for (i = 8; i >= 1; i--)
               printf("%02X ",buf[i]); 
            printf("\n");

            // SEARCH ROM
            if (TMFirst(session_handle,state_buffer) < 1)
              Exit_Prog("Search Fail\n",NO_DEVICE);

            ROM[0] = 0;
            TMRom(session_handle,state_buffer,ROM);   

            printf("SEARCH ROM: ");  
            for (j = 7; j >= 0; j--)
               printf("%02X ",ROM[j]);
            printf("\n\n");

            for (i = 0; i < 8; i++)
               if (ROM[i] != buf[i+1])
                  break;

            if (i != 8)
               Exit_Prog("ROM did not match\n",-1);
            else
               printf("ROM MATCH SUCCESS\n\n");

            if (loop == 0)
            {
               // OD SKIP
               if (TMTouchReset(session_handle) != 1)
                 Exit_Prog("No presence\n",NO_DEVICE);
         
               TMTouchByte(session_handle,0x3C);

               printf("Set to overdrive %d\n",TMOneWireCom(session_handle,0,1));
               printf("Speed %d\n\n",TMOneWireCom(session_handle,1,0));
            }
         }
         */
